@@ -3,6 +3,7 @@ from emmet.core.magnetism import MagnetismDoc
 
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from emmet.api.routes.magnetism.query_operators import MagneticQuery
+from emmet.api.core.global_header import GlobalHeaderProcessor
 
 
 def magnetism_resource(magnetism_store):
@@ -17,6 +18,7 @@ def magnetism_resource(magnetism_store):
                 MagnetismDoc, default_fields=["material_id", "last_updated"]
             ),
         ],
+        header_processor=GlobalHeaderProcessor(),
         tags=["Magnetism"],
         disable_validation=True,
     )
